<?php

namespace Litecms\Groupbusqueries\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Groupbusqueries\Http\Requests\GroupbusqueriesRequest;
use Litecms\Groupbusqueries\Interfaces\GroupbusqueriesRepositoryInterface;
use Litecms\Groupbusqueries\Models\Groupbusqueries;

/**
 * Resource controller class for groupbusqueries.
 */
class GroupbusqueriesResourceController extends BaseController
{

    /**
     * Initialize groupbusqueries resource controller.
     *
     * @param type GroupbusqueriesRepositoryInterface $groupbusqueries
     *
     * @return null
     */
    public function __construct(GroupbusqueriesRepositoryInterface $groupbusqueries)
    {
        parent::__construct();
        $this->repository = $groupbusqueries;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Groupbusqueries\Repositories\Criteria\GroupbusqueriesResourceCriteria::class);
    }

    /**
     * Display a list of groupbusqueries.
     *
     * @return Response
     */
    public function index(GroupbusqueriesRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Groupbusqueries\Repositories\Presenter\GroupbusqueriesPresenter::class)
                ->$function();
        }

        $groupbusqueries = $this->repository->paginate();

        return $this->response->title(trans('groupbusqueries::groupbusqueries.names'))
            ->view('groupbusqueries::groupbusqueries.index', true)
            ->data(compact('groupbusqueries'))
            ->output();
    }

    /**
     * Display groupbusqueries.
     *
     * @param Request $request
     * @param Model   $groupbusqueries
     *
     * @return Response
     */
    public function show(GroupbusqueriesRequest $request, Groupbusqueries $groupbusqueries)
    {

        if ($groupbusqueries->exists) {
            $view = 'groupbusqueries::groupbusqueries.show';
        } else {
            $view = 'groupbusqueries::groupbusqueries.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('groupbusqueries::groupbusqueries.name'))
            ->data(compact('groupbusqueries'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new groupbusqueries.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(GroupbusqueriesRequest $request)
    {

        $groupbusqueries = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('groupbusqueries::groupbusqueries.name')) 
            ->view('groupbusqueries::groupbusqueries.create', true) 
            ->data(compact('groupbusqueries'))
            ->output();
    }

    /**
     * Create new groupbusqueries.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(GroupbusqueriesRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $groupbusqueries                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('groupbusqueries::groupbusqueries.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('groupbusqueries/groupbusqueries/' . $groupbusqueries->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/groupbusqueries/groupbusqueries'))
                ->redirect();
        }

    }

    /**
     * Show groupbusqueries for editing.
     *
     * @param Request $request
     * @param Model   $groupbusqueries
     *
     * @return Response
     */
    public function edit(GroupbusqueriesRequest $request, Groupbusqueries $groupbusqueries)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('groupbusqueries::groupbusqueries.name'))
            ->view('groupbusqueries::groupbusqueries.edit', true)
            ->data(compact('groupbusqueries'))
            ->output();
    }

    /**
     * Update the groupbusqueries.
     *
     * @param Request $request
     * @param Model   $groupbusqueries
     *
     * @return Response
     */
    public function update(GroupbusqueriesRequest $request, Groupbusqueries $groupbusqueries)
    {
        try {
            $attributes = $request->all();

            $groupbusqueries->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('groupbusqueries::groupbusqueries.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('groupbusqueries/groupbusqueries/' . $groupbusqueries->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('groupbusqueries/groupbusqueries/' . $groupbusqueries->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the groupbusqueries.
     *
     * @param Model   $groupbusqueries
     *
     * @return Response
     */
    public function destroy(GroupbusqueriesRequest $request, Groupbusqueries $groupbusqueries)
    {
        try {

            $groupbusqueries->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('groupbusqueries::groupbusqueries.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('groupbusqueries/groupbusqueries/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('groupbusqueries/groupbusqueries/' . $groupbusqueries->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple groupbusqueries.
     *
     * @param Model   $groupbusqueries
     *
     * @return Response
     */
    public function delete(GroupbusqueriesRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('groupbusqueries::groupbusqueries.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('groupbusqueries/groupbusqueries'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/groupbusqueries/groupbusqueries'))
                ->redirect();
        }

    }

    /**
     * Restore deleted groupbusqueries.
     *
     * @param Model   $groupbusqueries
     *
     * @return Response
     */
    public function restore(GroupbusqueriesRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('groupbusqueries::groupbusqueries.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/groupbusqueries/groupbusqueries'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/groupbusqueries/groupbusqueries/'))
                ->redirect();
        }

    }

}
