<?php

namespace Litecms\Groupbusqueries\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Groupbusqueries\Models\Groupbusqueries;

class GroupbusqueriesPolicy
{

    /**
     * Determine if the given user can view the groupbusqueries.
     *
     * @param UserPolicy $user
     * @param Groupbusqueries $groupbusqueries
     *
     * @return bool
     */
    public function view(UserPolicy $user, Groupbusqueries $groupbusqueries)
    {
        if ($user->canDo('groupbusqueries.groupbusqueries.view') && $user->isAdmin()) {
            return true;
        }

        return $groupbusqueries->user_id == user_id() && $groupbusqueries->user_type == user_type();
    }

    /**
     * Determine if the given user can create a groupbusqueries.
     *
     * @param UserPolicy $user
     * @param Groupbusqueries $groupbusqueries
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('groupbusqueries.groupbusqueries.create');
    }

    /**
     * Determine if the given user can update the given groupbusqueries.
     *
     * @param UserPolicy $user
     * @param Groupbusqueries $groupbusqueries
     *
     * @return bool
     */
    public function update(UserPolicy $user, Groupbusqueries $groupbusqueries)
    {
        if ($user->canDo('groupbusqueries.groupbusqueries.edit') && $user->isAdmin()) {
            return true;
        }

        return $groupbusqueries->user_id == user_id() && $groupbusqueries->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given groupbusqueries.
     *
     * @param UserPolicy $user
     * @param Groupbusqueries $groupbusqueries
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Groupbusqueries $groupbusqueries)
    {
        return $groupbusqueries->user_id == user_id() && $groupbusqueries->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given groupbusqueries.
     *
     * @param UserPolicy $user
     * @param Groupbusqueries $groupbusqueries
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Groupbusqueries $groupbusqueries)
    {
        if ($user->canDo('groupbusqueries.groupbusqueries.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given groupbusqueries.
     *
     * @param UserPolicy $user
     * @param Groupbusqueries $groupbusqueries
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Groupbusqueries $groupbusqueries)
    {
        if ($user->canDo('groupbusqueries.groupbusqueries.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
